@@ -24,7 +24,7 @@ import os
 import sys
 import subprocess
 import pkg_resources
-from PyQt5 import QtWidgets, QtCore, QtGui  # pylint: disable=import-error
+from PyQt5 import QtWidgets, QtCore, QtGui, Qt  # pylint: disable=import-error
 
 from qubesadmin.utils import parse_size
 from qubesadmin import exc
@@ -82,6 +82,10 @@ class GlobalSettingsWindow(ui_globalsettingsdlg.Ui_GlobalSettings,
         self.buttonBox.accepted.connect(self.save_and_apply)
         self.buttonBox.rejected.connect(self.reject)
 
+        self.setWindowFlags(self.windowFlags() |
+                            Qt.Qt.WindowMaximizeButtonHint |
+                            Qt.Qt.WindowMinimizeButtonHint)
+
         self.__init_ux()
 
         self.__init_system_defaults__()
@@ -116,10 +120,11 @@ class GlobalSettingsWindow(ui_globalsettingsdlg.Ui_GlobalSettings,
         # The magical constants of 60 here are derived from margins set
         # in the .ui file
         req_width = self.scrollAreaWidgetContents_2.sizeHint().width() + 60
-        avail_width = self.app.desktop().availableGeometry().width() * 0.95
+        avail_width = int(self.app.desktop().availableGeometry().width() * 0.95)
 
         req_height = self.scrollAreaWidgetContents_2.sizeHint().height() + 60
-        avail_height = self.app.desktop().availableGeometry().height() * 0.95
+        avail_height = int(
+            self.app.desktop().availableGeometry().height() * 0.95)
 
         self.resize(min(req_width, avail_width), min(req_height, avail_height))
 
@@ -505,7 +510,7 @@ class GlobalSettingsWindow(ui_globalsettingsdlg.Ui_GlobalSettings,
         elif repos.get('qubes-dom0-current', {}).get('enabled', None):
             self.dom0_updates_repo.setCurrentIndex(0)
         else:
-            raise Exception(
+            raise exc.QubesException(
                 self.tr('Cannot detect enabled dom0 update repositories'))
 
         if repos.get('qubes-templates-itl-testing', {}).get('enabled', None):
@@ -513,8 +518,8 @@ class GlobalSettingsWindow(ui_globalsettingsdlg.Ui_GlobalSettings,
         elif repos.get('qubes-templates-itl', {}).get('enabled', None):
             self.itl_tmpl_updates_repo.setCurrentIndex(0)
         else:
-            raise Exception(self.tr('Cannot detect enabled ITL template update '
-                                    'repositories'))
+            raise exc.QubesException(self.tr('Cannot detect enabled ITL '
+                                             'template update repositories'))
 
         if repos.get(
                 'qubes-templates-community-testing', {}).get('enabled', None):
